@@ -198,7 +198,7 @@ def main(args=None):
     )
     parser.add_argument(
         "command",
-        help="specify the sub-command to run, possible choices: " "config, run, show",
+        help="specify the sub-command to run, possible choices: config, run, show",
     )
     parser.add_argument(
         "args",
