@@ -12,4 +12,4 @@
 
 from .file_utils import load, make_dir, dump 
 
-__all__ = ['file_utils', 'basis_utils', 'code_utils', 'load', 'make_dir', 'dump']
+__all__ = ['file_utils', 'basic_utils', 'code_utils', 'load', 'make_dir', 'dump']
